( cd /usr/bin ; rm -rf invgeod )
( cd /usr/bin ; ln -sf geod invgeod )
( cd /usr/bin ; rm -rf invproj )
( cd /usr/bin ; ln -sf proj invproj )
( cd /usr/lib ; rm -rf libproj.so.0 )
( cd /usr/lib ; ln -sf libproj.so.0.4.1 libproj.so.0 )
( cd /usr/lib ; rm -rf libproj.so )
( cd /usr/lib ; ln -sf libproj.so.0.4.1 libproj.so )
